==> aria2-1.7.2.tar.xz: aria2-1.7.2/src/ChecksumCheckIntegrityEntry.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "ChecksumCheckIntegrityEntry.h"
#include "RequestGroup.h"
#include "DownloadContext.h"
#include "FileEntry.h"
#include "IteratableChecksumValidator.h"
#include "DownloadEngine.h"
#include "PieceStorage.h"

namespace aria2 {

ChecksumCheckIntegrityEntry::ChecksumCheckIntegrityEntry(RequestGroup* requestGroup, Command* nextCommand):
  CheckIntegrityEntry(requestGroup, nextCommand) {}

ChecksumCheckIntegrityEntry::~ChecksumCheckIntegrityEntry() {}

bool ChecksumCheckIntegrityEntry::isValidationReady()
{
  return !_requestGroup->getDownloadContext()->getChecksum().empty() &&
    !_requestGroup->getDownloadContext()->getChecksumHashAlgo().empty();
}

void ChecksumCheckIntegrityEntry::initValidator()
{
  _validator.reset(new IteratableChecksumValidator
		   (_requestGroup->getDownloadContext(),
		    _requestGroup->getPieceStorage()));
  _validator->init();
}

void
ChecksumCheckIntegrityEntry::onDownloadFinished(std::deque<Command*>& commands,
						DownloadEngine* e)
{}

void
ChecksumCheckIntegrityEntry::onDownloadIncomplete(std::deque<Command*>& commands,
						  DownloadEngine* e)
{}

} // namespace aria2

==> aria2-1.10.0.tar.xz: aria2-1.10.0/src/ChecksumCheckIntegrityEntry.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "ChecksumCheckIntegrityEntry.h"
#include "RequestGroup.h"
#include "DownloadContext.h"
#include "FileEntry.h"
#include "IteratableChecksumValidator.h"
#include "DownloadEngine.h"
#include "PieceStorage.h"
#include "RequestGroupMan.h"
#include "FileAllocationEntry.h"
#include "ServerStatMan.h"

namespace aria2 {

ChecksumCheckIntegrityEntry::ChecksumCheckIntegrityEntry(RequestGroup* requestGroup, Command* nextCommand):
  CheckIntegrityEntry(requestGroup, nextCommand) {}

ChecksumCheckIntegrityEntry::~ChecksumCheckIntegrityEntry() {}

bool ChecksumCheckIntegrityEntry::isValidationReady()
{
  return !getRequestGroup()->getDownloadContext()->getChecksum().empty() &&
    !getRequestGroup()->getDownloadContext()->getChecksumHashAlgo().empty();
}

void ChecksumCheckIntegrityEntry::initValidator()
{
  SharedHandle<IteratableChecksumValidator> validator
    (new IteratableChecksumValidator(getRequestGroup()->getDownloadContext(),
                                     getRequestGroup()->getPieceStorage()));
  validator->init();
  setValidator(validator);
}

void
ChecksumCheckIntegrityEntry::onDownloadFinished
(std::vector<Command*>& commands, DownloadEngine* e)
{
  getRequestGroup()->getDownloadContext()->setChecksumVerified(true);
}

void
ChecksumCheckIntegrityEntry::onDownloadIncomplete
(std::vector<Command*>& commands, DownloadEngine* e)
{}

} // namespace aria2
